@@ -78,6 +78,7 @@ yahoohook::yahoohook() : abstracthook(yahoo), fonline(false), cid(0) {
     fcapabs.insert(hookcapab::files);
     fcapabs.insert(hookcapab::conferencing);
     fcapabs.insert(hookcapab::conferencesaretemporary);
+    fcapabs.insert(hookcapab::ssl);
 
     pager_host[0] = pager_port[0] = filetransfer_host[0] =
 	filetransfer_port[0] = webcam_host[0] = webcam_port[0] =
@@ -149,7 +150,9 @@ void yahoohook::connect() {
 
     cid = yahoo_init_with_attributes(acc.nickname.c_str(), acc.password.c_str(),
 	"pager_host", acc.server.c_str(),
-	"pager_port", acc.port, (char *) NULL);
+	"pager_port", acc.port,
+	"verify_ca", (acc.additional["ssl"] == "1")? 1 : 0,
+	(char *) NULL);
 
     yahoo_login(cid, stat2int[manualstatus]);
 
@@ -742,6 +745,12 @@ void yahoohook::login_response(int id, int succ, char *url) {
 	    yhook.setautostatus(yhook.manualstatus);
 	    yhook.timer_close = 0;
 	    break;
+	
+	case YAHOO_LOGIN_LOGOFF:
+	    yhook.fonline = yhook.fonline = false;
+	    yahoo_close(yhook.cid);
+	    face.log(_("+ [yahoo] cannot login"));
+	    break;
 
 	case YAHOO_LOGIN_PASSWD:
 	    yhook.fonline = yhook.fonline = false;
@@ -749,6 +758,12 @@ void yahoohook::login_response(int id, int succ, char *url) {
 	    face.log(_("+ [yahoo] cannot login: username and password mismatch"));
 	    break;
 
+	case YAHOO_LOGIN_UNAME:
+	    yhook.fonline = yhook.fonline = false;
+	    yahoo_close(yhook.cid);
+	    face.log(_("+ [yahoo] cannot login: username doesn't exist"));
+	    break;
+
 	case YAHOO_LOGIN_LOCK:
 	    yhook.fonline = yhook.fonline = false;
 	    yahoo_close(yhook.cid);
