@@ -27,6 +27,7 @@
 #include <dirent.h>
 #include <fstream>
 
+
 #if defined(__sun__) || defined(__NetBSD__) || defined(__sgi__)
 #include <sys/statvfs.h>
 #endif
@@ -68,7 +69,7 @@ icqconf::icqconf() {
 
     hideoffline = antispam = makelog = askaway = logtimestamps =
 	logonline = emacs = proxyssl = proxyconnect = notitles =
-	debug = timestampstothesecond = vi = false;
+	debug = timestampstothesecond = vi = autoawayx = false;
 
     timestampformat = DEFAULT_TIMESTAMP_FORMAT;
     logtimestampformat = DEFAULT_LOGTIMESTAMP_FORMAT;
@@ -83,13 +84,16 @@ icqconf::icqconf() {
     }
 
     // quick and dirty fix to support .centerim as well as .centericq
-    basedir = (string) getenv("HOME") + "/.centerim/";
+    char *home = getenv("HOME");
+    if( home != NULL ) {
+    basedir = string(home)  + "/.centerim/";
     if ( access(basedir.c_str(), F_OK) != 0 ) {
-        basedir = (string) getenv("HOME") + "/.centericq/";
+        basedir = string(home) + "/.centericq/";
         if ( access(basedir.c_str(), F_OK) != 0 ) {
-            basedir = (string) getenv("HOME") + "/.centerim/";
+            basedir = string(home) + "/.centerim/";
         }
     }
+    }
     screensocketpath = "/var/run/screen";
 
     defaultAuthMessage = "Please accept my authorization to add you to my contact list.";
@@ -158,6 +162,11 @@ void icqconf::setourid(const imaccount &im) {
 #endif
 		break;
 
+	    case yahoo:
+		if (i->additional.find("ssl") == i->additional.end())
+		    i->additional["ssl"] = "1";
+		break;
+	
 	    case livejournal:
 		if(i->additional.find("importfriends") == i->additional.end())
 		    i->additional["importfriends"] = "1";
@@ -265,9 +274,53 @@ void icqconf::setextstatus(protocolname pname, const string &amsg, imstatus stat
 void icqconf::checkdir() {
     string dname = getdirname();
     dname.erase(dname.size()-1);
+    const char * dirstr = dname.c_str();
+    const mode_t mask = umask (S_IRWXG | S_IRWXO); // All rights for group and other
 
-    if(access(dname.c_str(), F_OK))
-	mkdir(dname.c_str(), S_IRUSR | S_IWUSR | S_IXUSR);
+    if(access(dirstr, F_OK) == 0) {
+         // Directory allready exists check the permissions of the directory.
+        struct stat dir_stat;
+        if (  stat(dirstr, &dir_stat) == 0 &&
+              (dir_stat.st_mode & mask) != 0 ) {
+            DIR *pDir = NULL;
+            // group / other have some kind of permissions for this directory
+            // as mr Picard would have said: compensate!
+            chmod (dirstr, dir_stat.st_mode & ~mask);
+
+            // TODO: make sure that all subfiles got the right permissions, that is not done now.
+
+            // Make sure that atleast the configuration files are not readable for others
+            // Umask is set in centermain.cc, so all newly created files will be protected
+            // However if the ~/.centerim / ~/.centericq directory was created by an old
+            // version of centerim, then the rights will not be properly set up.
+
+            pDir = opendir(dirstr);
+
+            if (pDir != NULL) {
+                string tempString = string("");
+
+                struct dirent *pDirent = NULL;
+                while ( (pDirent = readdir(pDir)) != NULL ) {
+                    // only pDir->dname standaridized in POSIX?
+                    tempString = dirstr;
+                    tempString.append("/");
+                    tempString.append(pDirent->d_name);
+                    const char * pFilePath = tempString.c_str();
+
+                    if (stat(pFilePath, &dir_stat) == 0 &&
+                      (dir_stat.st_mode & mask) != 0 ) {
+                        chmod (pFilePath, dir_stat.st_mode & ~mask);
+                    }
+                }
+                closedir(pDir);
+            }
+        }
+    }
+    else{
+        // create the ~/.centerim directory since
+        // ~/.centerim / ~/.centericq does not exist.
+        mkdir(dname.c_str(), S_IRUSR | S_IWUSR | S_IXUSR);
+    }
 }
 
 void icqconf::load() {
@@ -545,6 +598,7 @@ void icqconf::loadmainconfig() {
 	    if(param == "vi") vi = true; else
 	    if(param == "autoaway") autoaway = atol(buf.c_str()); else
 	    if(param == "autona") autona = atol(buf.c_str()); else
+	    if(param == "auto_away_na_x") autoawayx = true; else
 	    if(param == "antispam") antispam = true; else
 	    if(param == "showopenedchats") setshowopenedchats(true); else
 	    if(param == "dropauthreq") dropauthreq = true; else
@@ -618,6 +672,7 @@ void icqconf::loadmainconfig() {
 void icqconf::save() {
     string fname = getconfigfname("config"), param;
     int away, na;
+    bool usex = false;
 
     if(enoughdiskspace()) {
 	ofstream f(fname.c_str());
@@ -631,10 +686,11 @@ void icqconf::save() {
 		f << "sockspass\t" << pass << endl;
 	    }
 
-	    getauto(away, na);
+	    getauto(away, na, usex);
 
 	    if(away) f << "autoaway\t" << i2str(away) << endl;
 	    if(na) f << "autona\t" << i2str(na) << endl;
+	    if(autoawayx) f << "auto_away_na_x" << endl;
 	    if(hideoffline) f << "hideoffline" << endl;
 	    if(emacs) f << "emacs" << endl;
 	    if(getquote()) f << "quotemsgs" << endl;
@@ -864,12 +920,12 @@ void icqconf::loadsounds() {
 
 	    switch(rs) {
 		case rscard:
-		    fo << "*\tmsg\tplay " << SHARE_DIR << "/msg.wav" << endl;
-		    fo << "*\turl\tplay " << SHARE_DIR << "/url.wav" << endl;
-		    fo << "*\temail\tplay " << SHARE_DIR << "/email.wav" << endl;
-		    fo << "*\tonline\tplay " << SHARE_DIR << "/online.wav" << endl;
-		    fo << "*\toffline\tplay " << SHARE_DIR << "/offline.wav" << endl;
-		    fo << "*\tsms\tplay " << SHARE_DIR << "/sms.wav" << endl;
+		    fo << "*\tmsg\taplay " << SHARE_DIR << "/msg.wav" << endl;
+		    fo << "*\turl\taplay " << SHARE_DIR << "/url.wav" << endl;
+		    fo << "*\temail\taplay " << SHARE_DIR << "/email.wav" << endl;
+		    fo << "*\tonline\taplay " << SHARE_DIR << "/online.wav" << endl;
+		    fo << "*\toffline\taplay " << SHARE_DIR << "/offline.wav" << endl;
+		    fo << "*\tsms\taplay " << SHARE_DIR << "/sms.wav" << endl;
 		    break;
 
 		case rsspeaker:
@@ -1077,17 +1133,19 @@ void icqconf::setcolormode(colormode c) {
     cm = c;
 }
 
-void icqconf::setauto(int away, int na) {
+void icqconf::setauto(int away, int na, bool usex) {
     autoaway = away;
     autona = na;
+    autoawayx = usex;
 
     if(away == na)
 	autoaway = 0;
 }
 
-void icqconf::getauto(int &away, int &na) const {
+void icqconf::getauto(int &away, int &na, bool& usex) const {
     away = autoaway;
     na = autona;
+    usex = autoawayx;
 
     if(away == na)
 	away = 0;
